void __stdcall AcquireSRWLockExclusive(int p0) {}
void __stdcall AcquireSRWLockShared(int p0) {}
void __stdcall ActivateActCtx(int p0, int p1) {}
void __stdcall ActivatePackageVirtualizationContext(int p0, int p1) {}
void __stdcall AddAtomA(int p0) {}
void __stdcall AddAtomW(int p0) {}
void __stdcall AddConsoleAliasA(int p0, int p1, int p2) {}
void __stdcall AddConsoleAliasW(int p0, int p1, int p2) {}
void __stdcall AddDllDirectory(int p0) {}
void __stdcall AddIntegrityLabelToBoundaryDescriptor(int p0, int p1) {}
void __stdcall AddRefActCtx(int p0) {}
void __stdcall AddResourceAttributeAce(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall AddSIDToBoundaryDescriptor(int p0, int p1) {}
void __stdcall AddScopedPolicyIDAce(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall AddSecureMemoryCacheCallback(int p0) {}
void __stdcall AddVectoredContinueHandler(int p0, int p1) {}
void __stdcall AddVectoredExceptionHandler(int p0, int p1) {}
void __stdcall AdjustCalendarDate(int p0, int p1, int p2) {}
void __stdcall AllocConsole() {}
void __stdcall AllocateUserPhysicalPages(int p0, int p1, int p2) {}
void __stdcall AllocateUserPhysicalPagesNuma(int p0, int p1, int p2, int p3) {}
void __stdcall AppPolicyGetClrCompat(int p0, int p1) {}
void __stdcall AppPolicyGetCreateFileAccess(int p0, int p1) {}
void __stdcall AppPolicyGetLifecycleManagement(int p0, int p1) {}
void __stdcall AppPolicyGetMediaFoundationCodecLoading(int p0, int p1) {}
void __stdcall AppPolicyGetProcessTerminationMethod(int p0, int p1) {}
void __stdcall AppPolicyGetShowDeveloperDiagnostic(int p0, int p1) {}
void __stdcall AppPolicyGetThreadInitializationType(int p0, int p1) {}
void __stdcall AppPolicyGetWindowingModel(int p0, int p1) {}
void __stdcall ApplicationRecoveryFinished(int p0) {}
void __stdcall ApplicationRecoveryInProgress(int p0) {}
void __stdcall AreFileApisANSI() {}
void __stdcall AreShortNamesEnabled(int p0, int p1) {}
void __stdcall AssignProcessToJobObject(int p0, int p1) {}
void __stdcall AttachConsole(int p0) {}
void __stdcall BackupRead(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall BackupSeek(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall BackupWrite(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall Beep(int p0, int p1) {}
void __stdcall BeginUpdateResourceA(int p0, int p1) {}
void __stdcall BeginUpdateResourceW(int p0, int p1) {}
void __stdcall BindIoCompletionCallback(int p0, int p1, int p2) {}
void __stdcall BuildCommDCBA(int p0, int p1) {}
void __stdcall BuildCommDCBAndTimeoutsA(int p0, int p1, int p2) {}
void __stdcall BuildCommDCBAndTimeoutsW(int p0, int p1, int p2) {}
void __stdcall BuildCommDCBW(int p0, int p1) {}
void __stdcall BuildIoRingFlushFile(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall BuildIoRingWriteFile(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8, int p9, int p10, int p11) {}
void __stdcall CallNamedPipeA(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall CallNamedPipeW(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall CallbackMayRunLong(int p0) {}
void __stdcall CancelDeviceWakeupRequest(int p0) {}
void __stdcall CancelIo(int p0) {}
void __stdcall CancelIoEx(int p0, int p1) {}
void __stdcall CancelSynchronousIo(int p0) {}
void __stdcall CancelThreadpoolIo(int p0) {}
void __stdcall CancelTimerQueueTimer(int p0, int p1) {}
void __stdcall CancelWaitableTimer(int p0) {}
void __stdcall CeipIsOptedIn() {}
void __stdcall ChangeTimerQueueTimer(int p0, int p1, int p2, int p3) {}
void __stdcall CheckIsMSIXPackage(int p0, int p1) {}
void __stdcall CheckNameLegalDOS8Dot3A(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall CheckNameLegalDOS8Dot3W(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall CheckRemoteDebuggerPresent(int p0, int p1) {}
void __stdcall CheckTokenCapability(int p0, int p1, int p2) {}
void __stdcall CheckTokenMembershipEx(int p0, int p1, int p2, int p3) {}
void __stdcall ClearCommBreak(int p0) {}
void __stdcall ClearCommError(int p0, int p1, int p2) {}
void __stdcall CloseHandle(int p0) {}
void __stdcall ClosePackageInfo(int p0) {}
void __stdcall ClosePrivateNamespace(int p0, int p1) {}
void __stdcall ClosePseudoConsole(int p0) {}
void __stdcall CloseThreadpool(int p0) {}
void __stdcall CloseThreadpoolCleanupGroup(int p0) {}
void __stdcall CloseThreadpoolCleanupGroupMembers(int p0, int p1, int p2) {}
void __stdcall CloseThreadpoolIo(int p0) {}
void __stdcall CloseThreadpoolTimer(int p0) {}
void __stdcall CloseThreadpoolWait(int p0) {}
void __stdcall CloseThreadpoolWork(int p0) {}
void __stdcall CommConfigDialogA(int p0, int p1, int p2) {}
void __stdcall CommConfigDialogW(int p0, int p1, int p2) {}
void __stdcall CompareFileTime(int p0, int p1) {}
void __stdcall CompareStringA(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall CompareStringEx(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8) {}
void __stdcall CompareStringOrdinal(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall CompareStringW(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall ConnectNamedPipe(int p0, int p1) {}
void __stdcall ContinueDebugEvent(int p0, int p1, int p2) {}
void __stdcall ConvertCalDateTimeToSystemTime(int p0, int p1) {}
void __stdcall ConvertDefaultLocale(int p0) {}
void __stdcall ConvertFiberToThread() {}
void __stdcall ConvertSystemTimeToCalDateTime(int p0, int p1, int p2) {}
void __stdcall ConvertThreadToFiber(int p0) {}
void __stdcall ConvertThreadToFiberEx(int p0, int p1) {}
void __stdcall CopyContext(int p0, int p1, int p2) {}
void __stdcall CopyFile2(int p0, int p1, int p2) {}
void __stdcall CopyFileA(int p0, int p1, int p2) {}
void __stdcall CopyFileExA(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall CopyFileExW(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall CopyFileTransactedA(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall CopyFileTransactedW(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall CopyFileW(int p0, int p1, int p2) {}
void __stdcall CopyLZFile(int p0, int p1) {}
void __stdcall CreateActCtxA(int p0) {}
void __stdcall CreateActCtxW(int p0) {}
void __stdcall CreateBoundaryDescriptorA(int p0, int p1) {}
void __stdcall CreateBoundaryDescriptorW(int p0, int p1) {}
void __stdcall CreateConsoleScreenBuffer(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall CreateDirectoryA(int p0, int p1) {}
void __stdcall CreateDirectoryExA(int p0, int p1, int p2) {}
void __stdcall CreateDirectoryExW(int p0, int p1, int p2) {}
void __stdcall CreateDirectoryTransactedA(int p0, int p1, int p2, int p3) {}
void __stdcall CreateDirectoryTransactedW(int p0, int p1, int p2, int p3) {}
void __stdcall CreateDirectoryW(int p0, int p1) {}
void __stdcall CreateEnclave(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall CreateEventA(int p0, int p1, int p2, int p3) {}
void __stdcall CreateEventExA(int p0, int p1, int p2, int p3) {}
void __stdcall CreateEventExW(int p0, int p1, int p2, int p3) {}
void __stdcall CreateEventW(int p0, int p1, int p2, int p3) {}
void __stdcall CreateFiber(int p0, int p1, int p2) {}
void __stdcall CreateFiberEx(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall CreateFile2(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall CreateFileA(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall CreateFileMappingA(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall CreateFileMappingFromApp(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall CreateFileMappingNumaA(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall CreateFileMappingNumaW(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall CreateFileMappingW(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall CreateFileTransactedA(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8, int p9) {}
void __stdcall CreateFileTransactedW(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8, int p9) {}
void __stdcall CreateFileW(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall CreateHardLinkA(int p0, int p1, int p2) {}
void __stdcall CreateHardLinkTransactedA(int p0, int p1, int p2, int p3) {}
void __stdcall CreateHardLinkTransactedW(int p0, int p1, int p2, int p3) {}
void __stdcall CreateHardLinkW(int p0, int p1, int p2) {}
void __stdcall CreateIoCompletionPort(int p0, int p1, int p2, int p3) {}
void __stdcall CreateJobObjectA(int p0, int p1) {}
void __stdcall CreateJobObjectW(int p0, int p1) {}
void __stdcall CreateJobSet(int p0, int p1, int p2) {}
void __stdcall CreateMailslotA(int p0, int p1, int p2, int p3) {}
void __stdcall CreateMailslotW(int p0, int p1, int p2, int p3) {}
void __stdcall CreateMemoryResourceNotification(int p0) {}
void __stdcall CreateMutexA(int p0, int p1, int p2) {}
void __stdcall CreateMutexExA(int p0, int p1, int p2, int p3) {}
void __stdcall CreateMutexExW(int p0, int p1, int p2, int p3) {}
void __stdcall CreateMutexW(int p0, int p1, int p2) {}
void __stdcall CreateNamedPipeA(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall CreateNamedPipeW(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall CreatePackageVirtualizationContext(int p0, int p1) {}
void __stdcall CreatePipe(int p0, int p1, int p2, int p3) {}
void __stdcall CreatePrivateNamespaceA(int p0, int p1, int p2) {}
void __stdcall CreatePrivateNamespaceW(int p0, int p1, int p2) {}
void __stdcall CreateProcessA(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8, int p9) {}
void __stdcall CreateProcessW(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8, int p9) {}
void __stdcall CreatePseudoConsole(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall CreateRemoteThread(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall CreateRemoteThreadEx(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall CreateSemaphoreA(int p0, int p1, int p2, int p3) {}
void __stdcall CreateSemaphoreExA(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall CreateSemaphoreExW(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall CreateSemaphoreW(int p0, int p1, int p2, int p3) {}
void __stdcall CreateSymbolicLinkA(int p0, int p1, int p2) {}
void __stdcall CreateSymbolicLinkTransactedA(int p0, int p1, int p2, int p3) {}
void __stdcall CreateSymbolicLinkTransactedW(int p0, int p1, int p2, int p3) {}
void __stdcall CreateSymbolicLinkW(int p0, int p1, int p2) {}
void __stdcall CreateTapePartition(int p0, int p1, int p2, int p3) {}
void __stdcall CreateThread(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall CreateThreadpool(int p0) {}
void __stdcall CreateThreadpoolCleanupGroup() {}
void __stdcall CreateThreadpoolIo(int p0, int p1, int p2, int p3) {}
void __stdcall CreateThreadpoolTimer(int p0, int p1, int p2) {}
void __stdcall CreateThreadpoolWait(int p0, int p1, int p2) {}
void __stdcall CreateThreadpoolWork(int p0, int p1, int p2) {}
void __stdcall CreateTimerQueue() {}
void __stdcall CreateTimerQueueTimer(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall CreateToolhelp32Snapshot(int p0, int p1) {}
void __stdcall CreateUmsCompletionList(int p0) {}
void __stdcall CreateUmsThreadContext(int p0) {}
void __stdcall CreateWaitableTimerA(int p0, int p1, int p2) {}
void __stdcall CreateWaitableTimerExA(int p0, int p1, int p2, int p3) {}
void __stdcall CreateWaitableTimerExW(int p0, int p1, int p2, int p3) {}
void __stdcall CreateWaitableTimerW(int p0, int p1, int p2) {}
void __stdcall DeactivateActCtx(int p0, int p1) {}
void __stdcall DeactivatePackageVirtualizationContext(int p0) {}
void __stdcall DebugActiveProcess(int p0) {}
void __stdcall DebugActiveProcessStop(int p0) {}
void __stdcall DebugBreak() {}
void __stdcall DebugBreakProcess(int p0) {}
void __stdcall DebugSetProcessKillOnExit(int p0) {}
void __stdcall DecodePointer(int p0) {}
void __stdcall DecodeSystemPointer(int p0) {}
void __stdcall DefineDosDeviceA(int p0, int p1, int p2) {}
void __stdcall DefineDosDeviceW(int p0, int p1, int p2) {}
void __stdcall DeleteAtom(int p0) {}
void __stdcall DeleteBoundaryDescriptor(int p0) {}
void __stdcall DeleteCriticalSection(int p0) {}
void __stdcall DeleteFiber(int p0) {}
void __stdcall DeleteFileA(int p0) {}
void __stdcall DeleteFileTransactedA(int p0, int p1) {}
void __stdcall DeleteFileTransactedW(int p0, int p1) {}
void __stdcall DeleteFileW(int p0) {}
void __stdcall DeleteProcThreadAttributeList(int p0) {}
void __stdcall DeleteSynchronizationBarrier(int p0) {}
void __stdcall DeleteTimerQueue(int p0) {}
void __stdcall DeleteTimerQueueEx(int p0, int p1) {}
void __stdcall DeleteTimerQueueTimer(int p0, int p1, int p2) {}
void __stdcall DeleteUmsCompletionList(int p0) {}
void __stdcall DeleteUmsThreadContext(int p0) {}
void __stdcall DeleteVolumeMountPointA(int p0) {}
void __stdcall DeleteVolumeMountPointW(int p0) {}
void __stdcall DequeueUmsCompletionListItems(int p0, int p1, int p2) {}
void __stdcall DeviceIoControl(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall DisableThreadLibraryCalls(int p0) {}
void __stdcall DisableThreadProfiling(int p0) {}
void __stdcall DisassociateCurrentThreadFromCallback(int p0) {}
void __stdcall DiscardVirtualMemory(int p0, int p1) {}
void __stdcall DisconnectNamedPipe(int p0) {}
void __stdcall DnsHostnameToComputerNameA(int p0, int p1, int p2) {}
void __stdcall DnsHostnameToComputerNameExW(int p0, int p1, int p2) {}
void __stdcall DnsHostnameToComputerNameW(int p0, int p1, int p2) {}
void __stdcall DosDateTimeToFileTime(int p0, int p1, int p2) {}
void __stdcall DuplicateHandle(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall DuplicatePackageVirtualizationContext(int p0, int p1) {}
void __stdcall EnableProcessOptionalXStateFeatures(int p0, int p1) {}
void __stdcall EnableThreadProfiling(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall EncodePointer(int p0) {}
void __stdcall EncodeSystemPointer(int p0) {}
void __stdcall EndUpdateResourceA(int p0, int p1) {}
void __stdcall EndUpdateResourceW(int p0, int p1) {}
void __stdcall EnterCriticalSection(int p0) {}
void __stdcall EnterSynchronizationBarrier(int p0, int p1) {}
void __stdcall EnterUmsSchedulingMode(int p0) {}
void __stdcall EnumCalendarInfoA(int p0, int p1, int p2, int p3) {}
void __stdcall EnumCalendarInfoExA(int p0, int p1, int p2, int p3) {}
void __stdcall EnumCalendarInfoExEx(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall EnumCalendarInfoExW(int p0, int p1, int p2, int p3) {}
void __stdcall EnumCalendarInfoW(int p0, int p1, int p2, int p3) {}
void __stdcall EnumDateFormatsA(int p0, int p1, int p2) {}
void __stdcall EnumDateFormatsExA(int p0, int p1, int p2) {}
void __stdcall EnumDateFormatsExEx(int p0, int p1, int p2, int p3) {}
void __stdcall EnumDateFormatsExW(int p0, int p1, int p2) {}
void __stdcall EnumDateFormatsW(int p0, int p1, int p2) {}
void __stdcall EnumLanguageGroupLocalesA(int p0, int p1, int p2, int p3) {}
void __stdcall EnumLanguageGroupLocalesW(int p0, int p1, int p2, int p3) {}
void __stdcall EnumResourceLanguagesA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall EnumResourceLanguagesExA(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall EnumResourceLanguagesExW(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall EnumResourceLanguagesW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall EnumResourceNamesA(int p0, int p1, int p2, int p3) {}
void __stdcall EnumResourceNamesExA(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall EnumResourceNamesExW(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall EnumResourceNamesW(int p0, int p1, int p2, int p3) {}
void __stdcall EnumResourceTypesA(int p0, int p1, int p2) {}
void __stdcall EnumResourceTypesExA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall EnumResourceTypesExW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall EnumResourceTypesW(int p0, int p1, int p2) {}
void __stdcall EnumSystemCodePagesA(int p0, int p1) {}
void __stdcall EnumSystemCodePagesW(int p0, int p1) {}
void __stdcall EnumSystemFirmwareTables(int p0, int p1, int p2) {}
void __stdcall EnumSystemGeoID(int p0, int p1, int p2) {}
void __stdcall EnumSystemGeoNames(int p0, int p1, int p2) {}
void __stdcall EnumSystemLanguageGroupsA(int p0, int p1, int p2) {}
void __stdcall EnumSystemLanguageGroupsW(int p0, int p1, int p2) {}
void __stdcall EnumSystemLocalesA(int p0, int p1) {}
void __stdcall EnumSystemLocalesEx(int p0, int p1, int p2, int p3) {}
void __stdcall EnumSystemLocalesW(int p0, int p1) {}
void __stdcall EnumTimeFormatsA(int p0, int p1, int p2) {}
void __stdcall EnumTimeFormatsEx(int p0, int p1, int p2, int p3) {}
void __stdcall EnumTimeFormatsW(int p0, int p1, int p2) {}
void __stdcall EnumUILanguagesA(int p0, int p1, int p2) {}
void __stdcall EnumUILanguagesW(int p0, int p1, int p2) {}
void __stdcall EraseTape(int p0, int p1, int p2) {}
void __stdcall EscapeCommFunction(int p0, int p1) {}
void __stdcall ExecuteUmsThread(int p0) {}
void __stdcall ExitProcess(int p0) {}
void __stdcall ExitThread(int p0) {}
void __stdcall ExpandEnvironmentStringsA(int p0, int p1, int p2) {}
void __stdcall ExpandEnvironmentStringsW(int p0, int p1, int p2) {}
void __stdcall ExpungeConsoleCommandHistoryA(int p0) {}
void __stdcall ExpungeConsoleCommandHistoryW(int p0) {}
void __stdcall FatalAppExitA(int p0, int p1) {}
void __stdcall FatalAppExitW(int p0, int p1) {}
void __stdcall FatalExit(int p0) {}
void __stdcall FileTimeToDosDateTime(int p0, int p1, int p2) {}
void __stdcall FileTimeToLocalFileTime(int p0, int p1) {}
void __stdcall FileTimeToSystemTime(int p0, int p1) {}
void __stdcall FillConsoleOutputAttribute(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall FillConsoleOutputCharacterA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall FillConsoleOutputCharacterW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall FindActCtxSectionGuid(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall FindActCtxSectionStringA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall FindActCtxSectionStringW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall FindAtomA(int p0) {}
void __stdcall FindAtomW(int p0) {}
void __stdcall FindClose(int p0) {}
void __stdcall FindCloseChangeNotification(int p0) {}
void __stdcall FindFirstChangeNotificationA(int p0, int p1, int p2) {}
void __stdcall FindFirstChangeNotificationW(int p0, int p1, int p2) {}
void __stdcall FindFirstFileA(int p0, int p1) {}
void __stdcall FindFirstFileExA(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall FindFirstFileExW(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall FindFirstFileNameTransactedW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall FindFirstFileNameW(int p0, int p1, int p2, int p3) {}
void __stdcall FindFirstFileTransactedA(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall FindFirstFileTransactedW(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall FindFirstFileW(int p0, int p1) {}
void __stdcall FindFirstStreamTransactedW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall FindFirstStreamW(int p0, int p1, int p2, int p3) {}
void __stdcall FindFirstVolumeA(int p0, int p1) {}
void __stdcall FindFirstVolumeMountPointA(int p0, int p1, int p2) {}
void __stdcall FindFirstVolumeMountPointW(int p0, int p1, int p2) {}
void __stdcall FindFirstVolumeW(int p0, int p1) {}
void __stdcall FindNLSString(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall FindNLSStringEx(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8, int p9) {}
void __stdcall FindNextChangeNotification(int p0) {}
void __stdcall FindNextFileA(int p0, int p1) {}
void __stdcall FindNextFileNameW(int p0, int p1, int p2) {}
void __stdcall FindNextFileW(int p0, int p1) {}
void __stdcall FindNextStreamW(int p0, int p1) {}
void __stdcall FindNextVolumeA(int p0, int p1, int p2) {}
void __stdcall FindNextVolumeMountPointA(int p0, int p1, int p2) {}
void __stdcall FindNextVolumeMountPointW(int p0, int p1, int p2) {}
void __stdcall FindNextVolumeW(int p0, int p1, int p2) {}
void __stdcall FindPackagesByPackageFamily(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall FindResourceA(int p0, int p1, int p2) {}
void __stdcall FindResourceExA(int p0, int p1, int p2, int p3) {}
void __stdcall FindResourceExW(int p0, int p1, int p2, int p3) {}
void __stdcall FindResourceW(int p0, int p1, int p2) {}
void __stdcall FindStringOrdinal(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall FindVolumeClose(int p0) {}
void __stdcall FindVolumeMountPointClose(int p0) {}
void __stdcall FlsAlloc(int p0) {}
void __stdcall FlsFree(int p0) {}
void __stdcall FlsGetValue(int p0) {}
void __stdcall FlsSetValue(int p0, int p1) {}
void __stdcall FlushConsoleInputBuffer(int p0) {}
void __stdcall FlushFileBuffers(int p0) {}
void __stdcall FlushInstructionCache(int p0, int p1, int p2) {}
void __stdcall FlushProcessWriteBuffers() {}
void __stdcall FlushViewOfFile(int p0, int p1) {}
void __stdcall FoldStringA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall FoldStringW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall FormatApplicationUserModelId(int p0, int p1, int p2, int p3) {}
void __stdcall FormatMessageA(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall FormatMessageW(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall FreeConsole() {}
void __stdcall FreeEnvironmentStringsA(int p0) {}
void __stdcall FreeEnvironmentStringsW(int p0) {}
void __stdcall FreeLibrary(int p0) {}
void __stdcall FreeLibraryAndExitThread(int p0, int p1) {}
void __stdcall FreeLibraryWhenCallbackReturns(int p0, int p1) {}
void __stdcall FreeMemoryJobObject(int p0) {}
void __stdcall FreeResource(int p0) {}
void __stdcall FreeUserPhysicalPages(int p0, int p1, int p2) {}
void __stdcall GenerateConsoleCtrlEvent(int p0, int p1) {}
void __stdcall GetACP() {}
void __stdcall GetActiveProcessorCount(int p0) {}
void __stdcall GetActiveProcessorGroupCount() {}
void __stdcall GetAppContainerAce(int p0, int p1, int p2, int p3) {}
void __stdcall GetAppContainerNamedObjectPath(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetApplicationRecoveryCallback(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetApplicationRestartSettings(int p0, int p1, int p2, int p3) {}
void __stdcall GetApplicationUserModelId(int p0, int p1, int p2) {}
void __stdcall GetAtomNameA(int p0, int p1, int p2) {}
void __stdcall GetAtomNameW(int p0, int p1, int p2) {}
void __stdcall GetBinaryTypeA(int p0, int p1) {}
void __stdcall GetBinaryTypeW(int p0, int p1) {}
void __stdcall GetCPInfo(int p0, int p1) {}
void __stdcall GetCPInfoExA(int p0, int p1, int p2) {}
void __stdcall GetCPInfoExW(int p0, int p1, int p2) {}
void __stdcall GetCachedSigningLevel(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall GetCalendarDateFormatEx(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall GetCalendarInfoA(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall GetCalendarInfoEx(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall GetCalendarInfoW(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall GetCalendarSupportedDateRange(int p0, int p1, int p2) {}
void __stdcall GetCommConfig(int p0, int p1, int p2) {}
void __stdcall GetCommMask(int p0, int p1) {}
void __stdcall GetCommModemStatus(int p0, int p1) {}
void __stdcall GetCommProperties(int p0, int p1) {}
void __stdcall GetCommState(int p0, int p1) {}
void __stdcall GetCommTimeouts(int p0, int p1) {}
void __stdcall GetCommandLineA() {}
void __stdcall GetCommandLineW() {}
void __stdcall GetCompressedFileSizeA(int p0, int p1) {}
void __stdcall GetCompressedFileSizeTransactedA(int p0, int p1, int p2) {}
void __stdcall GetCompressedFileSizeTransactedW(int p0, int p1, int p2) {}
void __stdcall GetCompressedFileSizeW(int p0, int p1) {}
void __stdcall GetComputerNameA(int p0, int p1) {}
void __stdcall GetComputerNameExA(int p0, int p1, int p2) {}
void __stdcall GetComputerNameExW(int p0, int p1, int p2) {}
void __stdcall GetComputerNameW(int p0, int p1) {}
void __stdcall GetConsoleAliasA(int p0, int p1, int p2, int p3) {}
void __stdcall GetConsoleAliasExesA(int p0, int p1) {}
void __stdcall GetConsoleAliasExesLengthA() {}
void __stdcall GetConsoleAliasExesLengthW() {}
void __stdcall GetConsoleAliasExesW(int p0, int p1) {}
void __stdcall GetConsoleAliasW(int p0, int p1, int p2, int p3) {}
void __stdcall GetConsoleAliasesA(int p0, int p1, int p2) {}
void __stdcall GetConsoleAliasesLengthA(int p0) {}
void __stdcall GetConsoleAliasesLengthW(int p0) {}
void __stdcall GetConsoleAliasesW(int p0, int p1, int p2) {}
void __stdcall GetConsoleCP() {}
void __stdcall GetConsoleCommandHistoryA(int p0, int p1, int p2) {}
void __stdcall GetConsoleCommandHistoryLengthA(int p0) {}
void __stdcall GetConsoleCommandHistoryLengthW(int p0) {}
void __stdcall GetConsoleCommandHistoryW(int p0, int p1, int p2) {}
void __stdcall GetConsoleCursorInfo(int p0, int p1) {}
void __stdcall GetConsoleDisplayMode(int p0) {}
void __stdcall GetConsoleFontSize(int p0, int p1) {}
void __stdcall GetConsoleHistoryInfo(int p0) {}
void __stdcall GetConsoleMode(int p0, int p1) {}
void __stdcall GetConsoleOriginalTitleA(int p0, int p1) {}
void __stdcall GetConsoleOriginalTitleW(int p0, int p1) {}
void __stdcall GetConsoleOutputCP() {}
void __stdcall GetConsoleProcessList(int p0, int p1) {}
void __stdcall GetConsoleScreenBufferInfo(int p0, int p1) {}
void __stdcall GetConsoleScreenBufferInfoEx(int p0, int p1) {}
void __stdcall GetConsoleSelectionInfo(int p0) {}
void __stdcall GetConsoleTitleA(int p0, int p1) {}
void __stdcall GetConsoleTitleW(int p0, int p1) {}
void __stdcall GetConsoleWindow() {}
void __stdcall GetCurrencyFormatA(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall GetCurrencyFormatEx(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall GetCurrencyFormatW(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall GetCurrentActCtx(int p0) {}
void __stdcall GetCurrentApplicationUserModelId(int p0, int p1) {}
void __stdcall GetCurrentConsoleFont(int p0, int p1, int p2) {}
void __stdcall GetCurrentConsoleFontEx(int p0, int p1, int p2) {}
void __stdcall GetCurrentDirectoryA(int p0, int p1) {}
void __stdcall GetCurrentDirectoryW(int p0, int p1) {}
void __stdcall GetCurrentPackageFamilyName(int p0, int p1) {}
void __stdcall GetCurrentPackageFullName(int p0, int p1) {}
void __stdcall GetCurrentPackageId(int p0, int p1) {}
void __stdcall GetCurrentPackageInfo(int p0, int p1, int p2, int p3) {}
void __stdcall GetCurrentPackageInfo3(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetCurrentPackagePath(int p0, int p1) {}
void __stdcall GetCurrentPackageVirtualizationContext() {}
void __stdcall GetCurrentProcess() {}
void __stdcall GetCurrentProcessId() {}
void __stdcall GetCurrentProcessorNumber() {}
void __stdcall GetCurrentProcessorNumberEx(int p0) {}
void __stdcall GetCurrentThread() {}
void __stdcall GetCurrentThreadId() {}
void __stdcall GetCurrentThreadStackLimits(int p0, int p1) {}
void __stdcall GetCurrentUmsThread() {}
void __stdcall GetDateFormatA(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall GetDateFormatEx(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall GetDateFormatW(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall GetDefaultCommConfigA(int p0, int p1, int p2) {}
void __stdcall GetDefaultCommConfigW(int p0, int p1, int p2) {}
void __stdcall GetDevicePowerState(int p0, int p1) {}
void __stdcall GetDiskFreeSpaceA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetDiskFreeSpaceExA(int p0, int p1, int p2, int p3) {}
void __stdcall GetDiskFreeSpaceExW(int p0, int p1, int p2, int p3) {}
void __stdcall GetDiskFreeSpaceW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetDiskSpaceInformationA(int p0, int p1) {}
void __stdcall GetDiskSpaceInformationW(int p0, int p1) {}
void __stdcall GetDllDirectoryA(int p0, int p1) {}
void __stdcall GetDllDirectoryW(int p0, int p1) {}
void __stdcall GetDriveTypeA(int p0) {}
void __stdcall GetDriveTypeW(int p0) {}
void __stdcall GetDurationFormat(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall GetDurationFormatEx(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall GetDynamicTimeZoneInformation(int p0) {}
void __stdcall GetEnabledXStateFeatures() {}
void __stdcall GetEnvironmentStrings() {}
void __stdcall GetEnvironmentStringsW() {}
void __stdcall GetEnvironmentVariableA(int p0, int p1, int p2) {}
void __stdcall GetEnvironmentVariableW(int p0, int p1, int p2) {}
void __stdcall GetErrorMode() {}
void __stdcall GetExitCodeProcess(int p0, int p1) {}
void __stdcall GetExitCodeThread(int p0, int p1) {}
void __stdcall GetExpandedNameA(int p0, int p1) {}
void __stdcall GetExpandedNameW(int p0, int p1) {}
void __stdcall GetFileAttributesA(int p0) {}
void __stdcall GetFileAttributesExA(int p0, int p1, int p2) {}
void __stdcall GetFileAttributesExW(int p0, int p1, int p2) {}
void __stdcall GetFileAttributesTransactedA(int p0, int p1, int p2, int p3) {}
void __stdcall GetFileAttributesTransactedW(int p0, int p1, int p2, int p3) {}
void __stdcall GetFileAttributesW(int p0) {}
void __stdcall GetFileBandwidthReservation(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall GetFileInformationByHandle(int p0, int p1) {}
void __stdcall GetFileInformationByHandleEx(int p0, int p1, int p2, int p3) {}
void __stdcall GetFileMUIInfo(int p0, int p1, int p2, int p3) {}
void __stdcall GetFileMUIPath(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall GetFileSize(int p0, int p1) {}
void __stdcall GetFileSizeEx(int p0, int p1) {}
void __stdcall GetFileTime(int p0, int p1, int p2, int p3) {}
void __stdcall GetFileType(int p0) {}
void __stdcall GetFinalPathNameByHandleA(int p0, int p1, int p2, int p3) {}
void __stdcall GetFinalPathNameByHandleW(int p0, int p1, int p2, int p3) {}
void __stdcall GetFirmwareEnvironmentVariableA(int p0, int p1, int p2, int p3) {}
void __stdcall GetFirmwareEnvironmentVariableExA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetFirmwareEnvironmentVariableExW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetFirmwareEnvironmentVariableW(int p0, int p1, int p2, int p3) {}
void __stdcall GetFirmwareType(int p0) {}
void __stdcall GetFullPathNameA(int p0, int p1, int p2, int p3) {}
void __stdcall GetFullPathNameTransactedA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetFullPathNameTransactedW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetFullPathNameW(int p0, int p1, int p2, int p3) {}
void __stdcall GetGeoInfoA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetGeoInfoEx(int p0, int p1, int p2, int p3) {}
void __stdcall GetGeoInfoW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetHandleInformation(int p0, int p1) {}
void __stdcall GetLargePageMinimum() {}
void __stdcall GetLargestConsoleWindowSize(int p0) {}
void __stdcall GetLastError() {}
void __stdcall GetLocalTime(int p0) {}
void __stdcall GetLocaleInfoA(int p0, int p1, int p2, int p3) {}
void __stdcall GetLocaleInfoEx(int p0, int p1, int p2, int p3) {}
void __stdcall GetLocaleInfoW(int p0, int p1, int p2, int p3) {}
void __stdcall GetLogicalDriveStringsA(int p0, int p1) {}
void __stdcall GetLogicalDriveStringsW(int p0, int p1) {}
void __stdcall GetLogicalDrives() {}
void __stdcall GetLogicalProcessorInformation(int p0, int p1) {}
void __stdcall GetLogicalProcessorInformationEx(int p0, int p1, int p2) {}
void __stdcall GetLongPathNameA(int p0, int p1, int p2) {}
void __stdcall GetLongPathNameTransactedA(int p0, int p1, int p2, int p3) {}
void __stdcall GetLongPathNameTransactedW(int p0, int p1, int p2, int p3) {}
void __stdcall GetLongPathNameW(int p0, int p1, int p2) {}
void __stdcall GetMachineTypeAttributes(int p0, int p1) {}
void __stdcall GetMailslotInfo(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetMaximumProcessorCount(int p0) {}
void __stdcall GetMaximumProcessorGroupCount() {}
void __stdcall GetMemoryErrorHandlingCapabilities(int p0) {}
void __stdcall GetModuleFileNameA(int p0, int p1, int p2) {}
void __stdcall GetModuleFileNameW(int p0, int p1, int p2) {}
void __stdcall GetModuleHandleA(int p0) {}
void __stdcall GetModuleHandleExA(int p0, int p1, int p2) {}
void __stdcall GetModuleHandleExW(int p0, int p1, int p2) {}
void __stdcall GetModuleHandleW(int p0) {}
void __stdcall GetNLSVersion(int p0, int p1, int p2) {}
void __stdcall GetNLSVersionEx(int p0, int p1, int p2) {}
void __stdcall GetNamedPipeClientComputerNameA(int p0, int p1, int p2) {}
void __stdcall GetNamedPipeClientComputerNameW(int p0, int p1, int p2) {}
void __stdcall GetNamedPipeClientProcessId(int p0, int p1) {}
void __stdcall GetNamedPipeClientSessionId(int p0, int p1) {}
void __stdcall GetNamedPipeHandleStateA(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall GetNamedPipeHandleStateW(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall GetNamedPipeInfo(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetNamedPipeServerProcessId(int p0, int p1) {}
void __stdcall GetNamedPipeServerSessionId(int p0, int p1) {}
void __stdcall GetNativeSystemInfo(int p0) {}
void __stdcall GetNextUmsListItem(int p0) {}
void __stdcall GetNumaAvailableMemoryNode(int p0, int p1) {}
void __stdcall GetNumaAvailableMemoryNodeEx(int p0, int p1) {}
void __stdcall GetNumaHighestNodeNumber(int p0) {}
void __stdcall GetNumaNodeNumberFromHandle(int p0, int p1) {}
void __stdcall GetNumaNodeProcessorMask(int p0, int p1) {}
void __stdcall GetNumaNodeProcessorMask2(int p0, int p1, int p2, int p3) {}
void __stdcall GetNumaNodeProcessorMaskEx(int p0, int p1) {}
void __stdcall GetNumaProcessorNode(int p0, int p1) {}
void __stdcall GetNumaProcessorNodeEx(int p0, int p1) {}
void __stdcall GetNumaProximityNode(int p0, int p1) {}
void __stdcall GetNumaProximityNodeEx(int p0, int p1) {}
void __stdcall GetNumberFormatA(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall GetNumberFormatEx(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall GetNumberFormatW(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall GetNumberOfConsoleInputEvents(int p0, int p1) {}
void __stdcall GetNumberOfConsoleMouseButtons(int p0) {}
void __stdcall GetOEMCP() {}
void __stdcall GetOverlappedResult(int p0, int p1, int p2, int p3) {}
void __stdcall GetOverlappedResultEx(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetPackageApplicationIds(int p0, int p1, int p2, int p3) {}
void __stdcall GetPackageFamilyName(int p0, int p1, int p2) {}
void __stdcall GetPackageFullName(int p0, int p1, int p2) {}
void __stdcall GetPackageId(int p0, int p1, int p2) {}
void __stdcall GetPackageInfo(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetPackagePath(int p0, int p1, int p2, int p3) {}
void __stdcall GetPackagePathByFullName(int p0, int p1, int p2) {}
void __stdcall GetPackagesByPackageFamily(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetPhysicallyInstalledSystemMemory(int p0) {}
void __stdcall GetPriorityClass(int p0) {}
void __stdcall GetPrivateProfileIntA(int p0, int p1, int p2, int p3) {}
void __stdcall GetPrivateProfileIntW(int p0, int p1, int p2, int p3) {}
void __stdcall GetPrivateProfileSectionA(int p0, int p1, int p2, int p3) {}
void __stdcall GetPrivateProfileSectionNamesA(int p0, int p1, int p2) {}
void __stdcall GetPrivateProfileSectionNamesW(int p0, int p1, int p2) {}
void __stdcall GetPrivateProfileSectionW(int p0, int p1, int p2, int p3) {}
void __stdcall GetPrivateProfileStringA(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall GetPrivateProfileStringW(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall GetPrivateProfileStructA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetPrivateProfileStructW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetProcAddress(int p0, int p1) {}
void __stdcall GetProcessAffinityMask(int p0, int p1, int p2) {}
void __stdcall GetProcessDEPPolicy(int p0, int p1, int p2) {}
void __stdcall GetProcessDefaultCpuSetMasks(int p0, int p1, int p2, int p3) {}
void __stdcall GetProcessDefaultCpuSets(int p0, int p1, int p2, int p3) {}
void __stdcall GetProcessGroupAffinity(int p0, int p1, int p2) {}
void __stdcall GetProcessHandleCount(int p0, int p1) {}
void __stdcall GetProcessHeap() {}
void __stdcall GetProcessHeaps(int p0, int p1) {}
void __stdcall GetProcessId(int p0) {}
void __stdcall GetProcessIdOfThread(int p0) {}
void __stdcall GetProcessInformation(int p0, int p1, int p2, int p3) {}
void __stdcall GetProcessIoCounters(int p0, int p1) {}
void __stdcall GetProcessMitigationPolicy(int p0, int p1, int p2, int p3) {}
void __stdcall GetProcessPreferredUILanguages(int p0, int p1, int p2, int p3) {}
void __stdcall GetProcessPriorityBoost(int p0, int p1) {}
void __stdcall GetProcessShutdownParameters(int p0, int p1) {}
void __stdcall GetProcessTimes(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetProcessVersion(int p0) {}
void __stdcall GetProcessWorkingSetSize(int p0, int p1, int p2) {}
void __stdcall GetProcessWorkingSetSizeEx(int p0, int p1, int p2, int p3) {}
void __stdcall GetProcessesInVirtualizationContext(int p0, int p1, int p2) {}
void __stdcall GetProcessorSystemCycleTime(int p0, int p1, int p2) {}
void __stdcall GetProductInfo(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetProfileIntA(int p0, int p1, int p2) {}
void __stdcall GetProfileIntW(int p0, int p1, int p2) {}
void __stdcall GetProfileSectionA(int p0, int p1, int p2) {}
void __stdcall GetProfileSectionW(int p0, int p1, int p2) {}
void __stdcall GetProfileStringA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetProfileStringW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetQueuedCompletionStatus(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetQueuedCompletionStatusEx(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall GetShortPathNameA(int p0, int p1, int p2) {}
void __stdcall GetShortPathNameW(int p0, int p1, int p2) {}
void __stdcall GetStagedPackagePathByFullName(int p0, int p1, int p2) {}
void __stdcall GetStartupInfoA(int p0) {}
void __stdcall GetStartupInfoW(int p0) {}
void __stdcall GetStdHandle(int p0) {}
void __stdcall GetStringScripts(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetStringTypeA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetStringTypeExA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetStringTypeExW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetStringTypeW(int p0, int p1, int p2, int p3) {}
void __stdcall GetSystemCpuSetInformation(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetSystemDEPPolicy() {}
void __stdcall GetSystemDefaultLCID() {}
void __stdcall GetSystemDefaultLangID() {}
void __stdcall GetSystemDefaultLocaleName(int p0, int p1) {}
void __stdcall GetSystemDefaultUILanguage() {}
void __stdcall GetSystemDirectoryA(int p0, int p1) {}
void __stdcall GetSystemDirectoryW(int p0, int p1) {}
void __stdcall GetSystemFileCacheSize(int p0, int p1, int p2) {}
void __stdcall GetSystemFirmwareTable(int p0, int p1, int p2, int p3) {}
void __stdcall GetSystemInfo(int p0) {}
void __stdcall GetSystemLeapSecondInformation(int p0, int p1) {}
void __stdcall GetSystemPowerStatus(int p0) {}
void __stdcall GetSystemPreferredUILanguages(int p0, int p1, int p2, int p3) {}
void __stdcall GetSystemRegistryQuota(int p0, int p1) {}
void __stdcall GetSystemTime(int p0) {}
void __stdcall GetSystemTimeAdjustment(int p0, int p1, int p2) {}
void __stdcall GetSystemTimeAsFileTime(int p0) {}
void __stdcall GetSystemTimePreciseAsFileTime(int p0) {}
void __stdcall GetSystemTimes(int p0, int p1, int p2) {}
void __stdcall GetSystemWindowsDirectoryA(int p0, int p1) {}
void __stdcall GetSystemWindowsDirectoryW(int p0, int p1) {}
void __stdcall GetSystemWow64DirectoryA(int p0, int p1) {}
void __stdcall GetSystemWow64DirectoryW(int p0, int p1) {}
void __stdcall GetTapeParameters(int p0, int p1, int p2, int p3) {}
void __stdcall GetTapePosition(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetTapeStatus(int p0) {}
void __stdcall GetTempFileNameA(int p0, int p1, int p2, int p3) {}
void __stdcall GetTempFileNameW(int p0, int p1, int p2, int p3) {}
void __stdcall GetTempPath2A(int p0, int p1) {}
void __stdcall GetTempPath2W(int p0, int p1) {}
void __stdcall GetTempPathA(int p0, int p1) {}
void __stdcall GetTempPathW(int p0, int p1) {}
void __stdcall GetThreadContext(int p0, int p1) {}
void __stdcall GetThreadDescription(int p0, int p1) {}
void __stdcall GetThreadEnabledXStateFeatures() {}
void __stdcall GetThreadErrorMode() {}
void __stdcall GetThreadGroupAffinity(int p0, int p1) {}
void __stdcall GetThreadIOPendingFlag(int p0, int p1) {}
void __stdcall GetThreadId(int p0) {}
void __stdcall GetThreadIdealProcessorEx(int p0, int p1) {}
void __stdcall GetThreadInformation(int p0, int p1, int p2, int p3) {}
void __stdcall GetThreadLocale() {}
void __stdcall GetThreadPreferredUILanguages(int p0, int p1, int p2, int p3) {}
void __stdcall GetThreadPriority(int p0) {}
void __stdcall GetThreadPriorityBoost(int p0, int p1) {}
void __stdcall GetThreadSelectedCpuSetMasks(int p0, int p1, int p2, int p3) {}
void __stdcall GetThreadSelectedCpuSets(int p0, int p1, int p2, int p3) {}
void __stdcall GetThreadSelectorEntry(int p0, int p1, int p2) {}
void __stdcall GetThreadTimes(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetThreadUILanguage() {}
void __stdcall GetTickCount() {}
void __stdcall GetTickCount64() {}
void __stdcall GetTimeFormatA(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall GetTimeFormatEx(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall GetTimeFormatW(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall GetTimeZoneInformation(int p0) {}
void __stdcall GetTimeZoneInformationForYear(int p0, int p1, int p2) {}
void __stdcall GetUILanguageInfo(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall GetUmsCompletionListEvent(int p0, int p1) {}
void __stdcall GetUmsSystemThreadInformation(int p0, int p1) {}
void __stdcall GetUserDefaultGeoName(int p0, int p1) {}
void __stdcall GetUserDefaultLCID() {}
void __stdcall GetUserDefaultLangID() {}
void __stdcall GetUserDefaultLocaleName(int p0, int p1) {}
void __stdcall GetUserDefaultUILanguage() {}
void __stdcall GetUserGeoID(int p0) {}
void __stdcall GetUserPreferredUILanguages(int p0, int p1, int p2, int p3) {}
void __stdcall GetVersion() {}
void __stdcall GetVersionExA(int p0) {}
void __stdcall GetVersionExW(int p0) {}
void __stdcall GetVolumeInformationA(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall GetVolumeInformationByHandleW(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall GetVolumeInformationW(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall GetVolumeNameForVolumeMountPointA(int p0, int p1, int p2) {}
void __stdcall GetVolumeNameForVolumeMountPointW(int p0, int p1, int p2) {}
void __stdcall GetVolumePathNameA(int p0, int p1, int p2) {}
void __stdcall GetVolumePathNameW(int p0, int p1, int p2) {}
void __stdcall GetVolumePathNamesForVolumeNameA(int p0, int p1, int p2, int p3) {}
void __stdcall GetVolumePathNamesForVolumeNameW(int p0, int p1, int p2, int p3) {}
void __stdcall GetWindowsDirectoryA(int p0, int p1) {}
void __stdcall GetWindowsDirectoryW(int p0, int p1) {}
void __stdcall GetWriteWatch(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall GetXStateFeaturesMask(int p0, int p1) {}
void __stdcall GlobalAddAtomA(int p0) {}
void __stdcall GlobalAddAtomExA(int p0, int p1) {}
void __stdcall GlobalAddAtomExW(int p0, int p1) {}
void __stdcall GlobalAddAtomW(int p0) {}
void __stdcall GlobalAlloc(int p0, int p1) {}
void __stdcall GlobalCompact(int p0) {}
void __stdcall GlobalDeleteAtom(int p0) {}
void __stdcall GlobalFindAtomA(int p0) {}
void __stdcall GlobalFindAtomW(int p0) {}
void __stdcall GlobalFix(int p0) {}
void __stdcall GlobalFlags(int p0) {}
void __stdcall GlobalFree(int p0) {}
void __stdcall GlobalGetAtomNameA(int p0, int p1, int p2) {}
void __stdcall GlobalGetAtomNameW(int p0, int p1, int p2) {}
void __stdcall GlobalHandle(int p0) {}
void __stdcall GlobalLock(int p0) {}
void __stdcall GlobalMemoryStatus(int p0) {}
void __stdcall GlobalMemoryStatusEx(int p0) {}
void __stdcall GlobalReAlloc(int p0, int p1, int p2) {}
void __stdcall GlobalSize(int p0) {}
void __stdcall GlobalUnWire(int p0) {}
void __stdcall GlobalUnfix(int p0) {}
void __stdcall GlobalUnlock(int p0) {}
void __stdcall GlobalWire(int p0) {}
void __stdcall Heap32First(int p0, int p1, int p2) {}
void __stdcall Heap32ListFirst(int p0, int p1) {}
void __stdcall Heap32ListNext(int p0, int p1) {}
void __stdcall Heap32Next(int p0) {}
void __stdcall HeapAlloc(int p0, int p1, int p2) {}
void __stdcall HeapCompact(int p0, int p1) {}
void __stdcall HeapCreate(int p0, int p1, int p2) {}
void __stdcall HeapDestroy(int p0) {}
void __stdcall HeapFree(int p0, int p1, int p2) {}
void __stdcall HeapLock(int p0) {}
void __stdcall HeapQueryInformation(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall HeapReAlloc(int p0, int p1, int p2, int p3) {}
void __stdcall HeapSetInformation(int p0, int p1, int p2, int p3) {}
void __stdcall HeapSize(int p0, int p1, int p2) {}
void __stdcall HeapSummary(int p0, int p1, int p2) {}
void __stdcall HeapUnlock(int p0) {}
void __stdcall HeapValidate(int p0, int p1, int p2) {}
void __stdcall HeapWalk(int p0, int p1) {}
void __stdcall IdnToNameprepUnicode(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall InitAtomTable(int p0) {}
void __stdcall InitOnceBeginInitialize(int p0, int p1, int p2, int p3) {}
void __stdcall InitOnceComplete(int p0, int p1, int p2) {}
void __stdcall InitOnceExecuteOnce(int p0, int p1, int p2, int p3) {}
void __stdcall InitOnceInitialize(int p0) {}
void __stdcall InitializeConditionVariable(int p0) {}
void __stdcall InitializeContext(int p0, int p1, int p2, int p3) {}
void __stdcall InitializeContext2(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall InitializeCriticalSection(int p0) {}
void __stdcall InitializeCriticalSectionAndSpinCount(int p0, int p1) {}
void __stdcall InitializeCriticalSectionEx(int p0, int p1, int p2) {}
void __stdcall InitializeEnclave(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall InitializeProcThreadAttributeList(int p0, int p1, int p2, int p3) {}
void __stdcall InitializeSListHead(int p0) {}
void __stdcall InitializeSRWLock(int p0) {}
void __stdcall InitializeSynchronizationBarrier(int p0, int p1, int p2) {}
void __stdcall InstallELAMCertificateInfo(int p0) {}
void __stdcall InterlockedFlushSList(int p0) {}
void __stdcall InterlockedPopEntrySList(int p0) {}
void __stdcall InterlockedPushEntrySList(int p0, int p1) {}
void __stdcall InterlockedPushListSListEx(int p0, int p1, int p2, int p3) {}
void __stdcall IsBadCodePtr(int p0) {}
void __stdcall IsBadHugeReadPtr(int p0, int p1) {}
void __stdcall IsBadHugeWritePtr(int p0, int p1) {}
void __stdcall IsBadReadPtr(int p0, int p1) {}
void __stdcall IsBadStringPtrA(int p0, int p1) {}
void __stdcall IsBadStringPtrW(int p0, int p1) {}
void __stdcall IsBadWritePtr(int p0, int p1) {}
void __stdcall IsCalendarLeapYear(int p0, int p1, int p2) {}
void __stdcall IsDBCSLeadByte(int p0) {}
void __stdcall IsDBCSLeadByteEx(int p0, int p1) {}
void __stdcall IsDebuggerPresent() {}
void __stdcall IsEnclaveTypeSupported(int p0) {}
void __stdcall IsNLSDefinedString(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall IsNativeVhdBoot(int p0) {}
void __stdcall IsNormalizedString(int p0, int p1, int p2) {}
void __stdcall IsProcessCritical(int p0, int p1) {}
void __stdcall IsProcessInJob(int p0, int p1, int p2) {}
void __stdcall IsProcessorFeaturePresent(int p0) {}
void __stdcall IsSystemResumeAutomatic() {}
void __stdcall IsThreadAFiber() {}
void __stdcall IsThreadpoolTimerSet(int p0) {}
void __stdcall IsUserCetAvailableInEnvironment(int p0) {}
void __stdcall IsValidCodePage(int p0) {}
void __stdcall IsValidLanguageGroup(int p0, int p1) {}
void __stdcall IsValidLocale(int p0, int p1) {}
void __stdcall IsValidLocaleName(int p0) {}
void __stdcall IsValidNLSVersion(int p0, int p1, int p2) {}
void __stdcall IsWow64GuestMachineSupported(int p0, int p1) {}
void __stdcall IsWow64Process(int p0, int p1) {}
void __stdcall IsWow64Process2(int p0, int p1, int p2) {}
void __stdcall K32EmptyWorkingSet(int p0) {}
void __stdcall K32EnumDeviceDrivers(int p0, int p1, int p2) {}
void __stdcall K32EnumPageFilesA(int p0, int p1) {}
void __stdcall K32EnumPageFilesW(int p0, int p1) {}
void __stdcall K32EnumProcessModules(int p0, int p1, int p2, int p3) {}
void __stdcall K32EnumProcessModulesEx(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall K32EnumProcesses(int p0, int p1, int p2) {}
void __stdcall K32GetDeviceDriverBaseNameA(int p0, int p1, int p2) {}
void __stdcall K32GetDeviceDriverBaseNameW(int p0, int p1, int p2) {}
void __stdcall K32GetDeviceDriverFileNameA(int p0, int p1, int p2) {}
void __stdcall K32GetDeviceDriverFileNameW(int p0, int p1, int p2) {}
void __stdcall K32GetMappedFileNameA(int p0, int p1, int p2, int p3) {}
void __stdcall K32GetMappedFileNameW(int p0, int p1, int p2, int p3) {}
void __stdcall K32GetModuleBaseNameA(int p0, int p1, int p2, int p3) {}
void __stdcall K32GetModuleBaseNameW(int p0, int p1, int p2, int p3) {}
void __stdcall K32GetModuleFileNameExA(int p0, int p1, int p2, int p3) {}
void __stdcall K32GetModuleFileNameExW(int p0, int p1, int p2, int p3) {}
void __stdcall K32GetModuleInformation(int p0, int p1, int p2, int p3) {}
void __stdcall K32GetPerformanceInfo(int p0, int p1) {}
void __stdcall K32GetProcessImageFileNameA(int p0, int p1, int p2) {}
void __stdcall K32GetProcessImageFileNameW(int p0, int p1, int p2) {}
void __stdcall K32GetProcessMemoryInfo(int p0, int p1, int p2) {}
void __stdcall K32GetWsChanges(int p0, int p1, int p2) {}
void __stdcall K32GetWsChangesEx(int p0, int p1, int p2) {}
void __stdcall K32InitializeProcessForWsWatch(int p0) {}
void __stdcall K32QueryWorkingSet(int p0, int p1, int p2) {}
void __stdcall K32QueryWorkingSetEx(int p0, int p1, int p2) {}
void __stdcall LCIDToLocaleName(int p0, int p1, int p2, int p3) {}
void __stdcall LCMapStringA(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall LCMapStringEx(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8) {}
void __stdcall LCMapStringW(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall LZClose(int p0) {}
void __stdcall LZCopy(int p0, int p1) {}
void __stdcall LZDone() {}
void __stdcall LZInit(int p0) {}
void __stdcall LZOpenFileA(int p0, int p1, int p2) {}
void __stdcall LZOpenFileW(int p0, int p1, int p2) {}
void __stdcall LZRead(int p0, int p1, int p2) {}
void __stdcall LZSeek(int p0, int p1, int p2) {}
void __stdcall LZStart() {}
void __stdcall LeaveCriticalSection(int p0) {}
void __stdcall LeaveCriticalSectionWhenCallbackReturns(int p0, int p1) {}
void __stdcall LoadEnclaveData(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8) {}
void __stdcall LoadLibraryA(int p0) {}
void __stdcall LoadLibraryExA(int p0, int p1, int p2) {}
void __stdcall LoadLibraryExW(int p0, int p1, int p2) {}
void __stdcall LoadLibraryW(int p0) {}
void __stdcall LoadModule(int p0, int p1) {}
void __stdcall LoadPackagedLibrary(int p0, int p1) {}
void __stdcall LoadResource(int p0, int p1) {}
void __stdcall LocalAlloc(int p0, int p1) {}
void __stdcall LocalCompact(int p0) {}
void __stdcall LocalFileTimeToFileTime(int p0, int p1) {}
void __stdcall LocalFileTimeToLocalSystemTime(int p0, int p1, int p2) {}
void __stdcall LocalFlags(int p0) {}
void __stdcall LocalFree(int p0) {}
void __stdcall LocalHandle(int p0) {}
void __stdcall LocalLock(int p0) {}
void __stdcall LocalReAlloc(int p0, int p1, int p2) {}
void __stdcall LocalShrink(int p0, int p1) {}
void __stdcall LocalSize(int p0) {}
void __stdcall LocalSystemTimeToLocalFileTime(int p0, int p1, int p2) {}
void __stdcall LocalUnlock(int p0) {}
void __stdcall LocaleNameToLCID(int p0, int p1) {}
void __stdcall LocateXStateFeature(int p0, int p1, int p2) {}
void __stdcall LockFile(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall LockFileEx(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall LockResource(int p0) {}
void __stdcall MapUserPhysicalPages(int p0, int p1, int p2) {}
void __stdcall MapUserPhysicalPagesScatter(int p0, int p1, int p2) {}
void __stdcall MapViewOfFile(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall MapViewOfFileEx(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall MapViewOfFileExNuma(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall MapViewOfFileFromApp(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall Module32First(int p0, int p1) {}
void __stdcall Module32FirstW(int p0, int p1) {}
void __stdcall Module32Next(int p0, int p1) {}
void __stdcall Module32NextW(int p0, int p1) {}
void __stdcall MoveFileA(int p0, int p1) {}
void __stdcall MoveFileExA(int p0, int p1, int p2) {}
void __stdcall MoveFileExW(int p0, int p1, int p2) {}
void __stdcall MoveFileTransactedA(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall MoveFileTransactedW(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall MoveFileW(int p0, int p1) {}
void __stdcall MoveFileWithProgressA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall MoveFileWithProgressW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall MulDiv(int p0, int p1, int p2) {}
void __stdcall MultiByteToWideChar(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall NeedCurrentDirectoryForExePathA(int p0) {}
void __stdcall NeedCurrentDirectoryForExePathW(int p0) {}
void __stdcall NormalizeString(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall NotifyUILanguageChange(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall OOBEComplete(int p0) {}
void __stdcall OfferVirtualMemory(int p0, int p1, int p2) {}
void __stdcall OpenEventA(int p0, int p1, int p2) {}
void __stdcall OpenEventW(int p0, int p1, int p2) {}
void __stdcall OpenFile(int p0, int p1, int p2) {}
void __stdcall OpenFileById(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall OpenFileMappingA(int p0, int p1, int p2) {}
void __stdcall OpenFileMappingW(int p0, int p1, int p2) {}
void __stdcall OpenJobObjectA(int p0, int p1, int p2) {}
void __stdcall OpenJobObjectW(int p0, int p1, int p2) {}
void __stdcall OpenMutexA(int p0, int p1, int p2) {}
void __stdcall OpenMutexW(int p0, int p1, int p2) {}
void __stdcall OpenPackageInfoByFullName(int p0, int p1, int p2) {}
void __stdcall OpenPrivateNamespaceA(int p0, int p1) {}
void __stdcall OpenPrivateNamespaceW(int p0, int p1) {}
void __stdcall OpenProcess(int p0, int p1, int p2) {}
void __stdcall OpenSemaphoreA(int p0, int p1, int p2) {}
void __stdcall OpenSemaphoreW(int p0, int p1, int p2) {}
void __stdcall OpenThread(int p0, int p1, int p2) {}
void __stdcall OpenWaitableTimerA(int p0, int p1, int p2) {}
void __stdcall OpenWaitableTimerW(int p0, int p1, int p2) {}
void __stdcall OutputDebugStringA(int p0) {}
void __stdcall OutputDebugStringW(int p0) {}
void __stdcall PackageFamilyNameFromFullName(int p0, int p1, int p2) {}
void __stdcall PackageFamilyNameFromId(int p0, int p1, int p2) {}
void __stdcall PackageFullNameFromId(int p0, int p1, int p2) {}
void __stdcall PackageIdFromFullName(int p0, int p1, int p2, int p3) {}
void __stdcall PackageNameAndPublisherIdFromFamilyName(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall ParseApplicationUserModelId(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall PeekConsoleInputA(int p0, int p1, int p2, int p3) {}
void __stdcall PeekConsoleInputW(int p0, int p1, int p2, int p3) {}
void __stdcall PeekNamedPipe(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall PostQueuedCompletionStatus(int p0, int p1, int p2, int p3) {}
void __stdcall PowerClearRequest(int p0, int p1) {}
void __stdcall PowerCreateRequest(int p0) {}
void __stdcall PowerSetRequest(int p0, int p1) {}
void __stdcall PrefetchVirtualMemory(int p0, int p1, int p2, int p3) {}
void __stdcall PrepareTape(int p0, int p1, int p2) {}
void __stdcall Process32First(int p0, int p1) {}
void __stdcall Process32FirstW(int p0, int p1) {}
void __stdcall Process32Next(int p0, int p1) {}
void __stdcall Process32NextW(int p0, int p1) {}
void __stdcall ProcessIdToSessionId(int p0, int p1) {}
void __stdcall PssCaptureSnapshot(int p0, int p1, int p2, int p3) {}
void __stdcall PssDuplicateSnapshot(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall PssFreeSnapshot(int p0, int p1) {}
void __stdcall PssQuerySnapshot(int p0, int p1, int p2, int p3) {}
void __stdcall PssWalkMarkerCreate(int p0, int p1) {}
void __stdcall PssWalkMarkerFree(int p0) {}
void __stdcall PssWalkMarkerGetPosition(int p0, int p1) {}
void __stdcall PssWalkMarkerSeekToBeginning(int p0) {}
void __stdcall PssWalkMarkerSetPosition(int p0, int p1) {}
void __stdcall PssWalkSnapshot(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall PulseEvent(int p0) {}
void __stdcall PurgeComm(int p0, int p1) {}
void __stdcall QueryActCtxSettingsW(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall QueryActCtxW(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall QueryDepthSList(int p0) {}
void __stdcall QueryDosDeviceA(int p0, int p1, int p2) {}
void __stdcall QueryDosDeviceW(int p0, int p1, int p2) {}
void __stdcall QueryFullProcessImageNameA(int p0, int p1, int p2, int p3) {}
void __stdcall QueryFullProcessImageNameW(int p0, int p1, int p2, int p3) {}
void __stdcall QueryIdleProcessorCycleTime(int p0, int p1) {}
void __stdcall QueryIdleProcessorCycleTimeEx(int p0, int p1, int p2) {}
void __stdcall QueryInformationJobObject(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall QueryIoRateControlInformationJobObject(int p0, int p1, int p2, int p3) {}
void __stdcall QueryMemoryResourceNotification(int p0, int p1) {}
void __stdcall QueryPerformanceCounter(int p0) {}
void __stdcall QueryPerformanceFrequency(int p0) {}
void __stdcall QueryProcessAffinityUpdateMode(int p0, int p1) {}
void __stdcall QueryProcessCycleTime(int p0, int p1) {}
void __stdcall QueryProtectedPolicy(int p0, int p1) {}
void __stdcall QueryThreadCycleTime(int p0, int p1) {}
void __stdcall QueryThreadProfiling(int p0, int p1) {}
void __stdcall QueryThreadpoolStackInformation(int p0, int p1) {}
void __stdcall QueryUmsThreadInformation(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall QueryUnbiasedInterruptTime(int p0) {}
void __stdcall QueueUserAPC(int p0, int p1, int p2) {}
void __stdcall QueueUserAPC2(int p0, int p1, int p2, int p3) {}
void __stdcall QueueUserWorkItem(int p0, int p1, int p2) {}
void __stdcall RaiseException(int p0, int p1, int p2, int p3) {}
void __stdcall RaiseFailFastException(int p0, int p1, int p2) {}
void __stdcall ReOpenFile(int p0, int p1, int p2, int p3) {}
void __stdcall ReadConsoleA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall ReadConsoleInputA(int p0, int p1, int p2, int p3) {}
void __stdcall ReadConsoleInputW(int p0, int p1, int p2, int p3) {}
void __stdcall ReadConsoleOutputA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall ReadConsoleOutputAttribute(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall ReadConsoleOutputCharacterA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall ReadConsoleOutputCharacterW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall ReadConsoleOutputW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall ReadConsoleW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall ReadDirectoryChangesExW(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8) {}
void __stdcall ReadDirectoryChangesW(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall ReadFile(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall ReadFileEx(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall ReadFileScatter(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall ReadProcessMemory(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall ReadThreadProfilingData(int p0, int p1, int p2) {}
void __stdcall ReclaimVirtualMemory(int p0, int p1) {}
void __stdcall RegisterApplicationRecoveryCallback(int p0, int p1, int p2, int p3) {}
void __stdcall RegisterApplicationRestart(int p0, int p1) {}
void __stdcall RegisterBadMemoryNotification(int p0) {}
void __stdcall RegisterWaitForSingleObject(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall RegisterWaitUntilOOBECompleted(int p0, int p1, int p2) {}
void __stdcall ReleaseActCtx(int p0) {}
void __stdcall ReleaseMutex(int p0) {}
void __stdcall ReleaseMutexWhenCallbackReturns(int p0, int p1) {}
void __stdcall ReleasePackageVirtualizationContext(int p0) {}
void __stdcall ReleaseSRWLockExclusive(int p0) {}
void __stdcall ReleaseSRWLockShared(int p0) {}
void __stdcall ReleaseSemaphore(int p0, int p1, int p2) {}
void __stdcall ReleaseSemaphoreWhenCallbackReturns(int p0, int p1, int p2) {}
void __stdcall RemoveDirectoryA(int p0) {}
void __stdcall RemoveDirectoryTransactedA(int p0, int p1) {}
void __stdcall RemoveDirectoryTransactedW(int p0, int p1) {}
void __stdcall RemoveDirectoryW(int p0) {}
void __stdcall RemoveDllDirectory(int p0) {}
void __stdcall RemoveSecureMemoryCacheCallback(int p0) {}
void __stdcall RemoveVectoredContinueHandler(int p0) {}
void __stdcall RemoveVectoredExceptionHandler(int p0) {}
void __stdcall ReplaceFileA(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall ReplaceFileW(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall ReplacePartitionUnit(int p0, int p1, int p2) {}
void __stdcall RequestDeviceWakeup(int p0) {}
void __stdcall RequestWakeupLatency(int p0) {}
void __stdcall ResetEvent(int p0) {}
void __stdcall ResetWriteWatch(int p0, int p1) {}
void __stdcall ResizePseudoConsole(int p0, int p1) {}
void __stdcall ResolveLocaleName(int p0, int p1, int p2) {}
void __stdcall RestoreThreadPreferredUILanguages(int p0) {}
void __stdcall ResumeThread(int p0) {}
void __stdcall RtlAddFunctionTable(int p0, int p1, int p2, int p3) {}
void __stdcall RtlCaptureContext(int p0) {}
void __stdcall RtlCaptureContext2(int p0) {}
void __stdcall RtlCaptureStackBackTrace(int p0, int p1, int p2, int p3) {}
void __stdcall RtlCompareMemory(int p0, int p1, int p2) {}
void __stdcall RtlDeleteFunctionTable(int p0) {}
void __stdcall RtlInstallFunctionTableCallback(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall RtlLookupFunctionEntry(int p0, int p1, int p2, int p3) {}
void __stdcall RtlPcToFileHeader(int p0, int p1) {}
void __stdcall RtlRaiseException(int p0) {}
void __cdecl RtlRestoreContext() {}
void __stdcall RtlUnwind(int p0, int p1, int p2, int p3) {}
void __stdcall RtlUnwindEx(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall RtlVirtualUnwind(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8, int p9) {}
void __stdcall ScrollConsoleScreenBufferA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall ScrollConsoleScreenBufferW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall SearchPathA(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall SearchPathW(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall SetCachedSigningLevel(int p0, int p1, int p2, int p3) {}
void __stdcall SetCalendarInfoA(int p0, int p1, int p2, int p3) {}
void __stdcall SetCalendarInfoW(int p0, int p1, int p2, int p3) {}
void __stdcall SetCommBreak(int p0) {}
void __stdcall SetCommConfig(int p0, int p1, int p2) {}
void __stdcall SetCommMask(int p0, int p1) {}
void __stdcall SetCommState(int p0, int p1) {}
void __stdcall SetCommTimeouts(int p0, int p1) {}
void __stdcall SetComputerNameA(int p0) {}
void __stdcall SetComputerNameEx2W(int p0, int p1, int p2) {}
void __stdcall SetComputerNameExA(int p0, int p1) {}
void __stdcall SetComputerNameExW(int p0, int p1) {}
void __stdcall SetComputerNameW(int p0) {}
void __stdcall SetConsoleActiveScreenBuffer(int p0) {}
void __stdcall SetConsoleCP(int p0) {}
void __stdcall SetConsoleCtrlHandler(int p0, int p1) {}
void __stdcall SetConsoleCursorInfo(int p0, int p1) {}
void __stdcall SetConsoleCursorPosition(int p0, int p1) {}
void __stdcall SetConsoleDisplayMode(int p0, int p1, int p2) {}
void __stdcall SetConsoleHistoryInfo(int p0) {}
void __stdcall SetConsoleMode(int p0, int p1) {}
void __stdcall SetConsoleNumberOfCommandsA(int p0, int p1) {}
void __stdcall SetConsoleNumberOfCommandsW(int p0, int p1) {}
void __stdcall SetConsoleOutputCP(int p0) {}
void __stdcall SetConsoleScreenBufferInfoEx(int p0, int p1) {}
void __stdcall SetConsoleScreenBufferSize(int p0, int p1) {}
void __stdcall SetConsoleTextAttribute(int p0, int p1) {}
void __stdcall SetConsoleTitleA(int p0) {}
void __stdcall SetConsoleTitleW(int p0) {}
void __stdcall SetConsoleWindowInfo(int p0, int p1, int p2) {}
void __stdcall SetCriticalSectionSpinCount(int p0, int p1) {}
void __stdcall SetCurrentConsoleFontEx(int p0, int p1, int p2) {}
void __stdcall SetCurrentDirectoryA(int p0) {}
void __stdcall SetCurrentDirectoryW(int p0) {}
void __stdcall SetDefaultCommConfigA(int p0, int p1, int p2) {}
void __stdcall SetDefaultCommConfigW(int p0, int p1, int p2) {}
void __stdcall SetDefaultDllDirectories(int p0) {}
void __stdcall SetDllDirectoryA(int p0) {}
void __stdcall SetDllDirectoryW(int p0) {}
void __stdcall SetDynamicTimeZoneInformation(int p0) {}
void __stdcall SetEndOfFile(int p0) {}
void __stdcall SetEnvironmentStringsA(int p0) {}
void __stdcall SetEnvironmentStringsW(int p0) {}
void __stdcall SetEnvironmentVariableA(int p0, int p1) {}
void __stdcall SetEnvironmentVariableW(int p0, int p1) {}
void __stdcall SetErrorMode(int p0) {}
void __stdcall SetEvent(int p0) {}
void __stdcall SetEventWhenCallbackReturns(int p0, int p1) {}
void __stdcall SetFileApisToANSI() {}
void __stdcall SetFileApisToOEM() {}
void __stdcall SetFileAttributesA(int p0, int p1) {}
void __stdcall SetFileAttributesTransactedA(int p0, int p1, int p2) {}
void __stdcall SetFileAttributesTransactedW(int p0, int p1, int p2) {}
void __stdcall SetFileAttributesW(int p0, int p1) {}
void __stdcall SetFileBandwidthReservation(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall SetFileCompletionNotificationModes(int p0, int p1) {}
void __stdcall SetFileInformationByHandle(int p0, int p1, int p2, int p3) {}
void __stdcall SetFileIoOverlappedRange(int p0, int p1, int p2) {}
void __stdcall SetFilePointer(int p0, int p1, int p2, int p3) {}
void __stdcall SetFilePointerEx(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall SetFileShortNameA(int p0, int p1) {}
void __stdcall SetFileShortNameW(int p0, int p1) {}
void __stdcall SetFileTime(int p0, int p1, int p2, int p3) {}
void __stdcall SetFileValidData(int p0, int p1, int p2) {}
void __stdcall SetFirmwareEnvironmentVariableA(int p0, int p1, int p2, int p3) {}
void __stdcall SetFirmwareEnvironmentVariableExA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall SetFirmwareEnvironmentVariableExW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall SetFirmwareEnvironmentVariableW(int p0, int p1, int p2, int p3) {}
void __stdcall SetHandleCount(int p0) {}
void __stdcall SetHandleInformation(int p0, int p1, int p2) {}
void __stdcall SetInformationJobObject(int p0, int p1, int p2, int p3) {}
void __stdcall SetIoRateControlInformationJobObject(int p0, int p1) {}
void __stdcall SetLastError(int p0) {}
void __stdcall SetLocalTime(int p0) {}
void __stdcall SetLocaleInfoA(int p0, int p1, int p2) {}
void __stdcall SetLocaleInfoW(int p0, int p1, int p2) {}
void __stdcall SetMailslotInfo(int p0, int p1) {}
void __stdcall SetMessageWaitingIndicator(int p0, int p1) {}
void __stdcall SetNamedPipeHandleState(int p0, int p1, int p2, int p3) {}
void __stdcall SetPriorityClass(int p0, int p1) {}
void __stdcall SetProcessAffinityMask(int p0, int p1) {}
void __stdcall SetProcessAffinityUpdateMode(int p0, int p1) {}
void __stdcall SetProcessDEPPolicy(int p0) {}
void __stdcall SetProcessDefaultCpuSetMasks(int p0, int p1, int p2) {}
void __stdcall SetProcessDefaultCpuSets(int p0, int p1, int p2) {}
void __stdcall SetProcessDynamicEHContinuationTargets(int p0, int p1, int p2) {}
void __stdcall SetProcessDynamicEnforcedCetCompatibleRanges(int p0, int p1, int p2) {}
void __stdcall SetProcessInformation(int p0, int p1, int p2, int p3) {}
void __stdcall SetProcessMitigationPolicy(int p0, int p1, int p2) {}
void __stdcall SetProcessPreferredUILanguages(int p0, int p1, int p2) {}
void __stdcall SetProcessPriorityBoost(int p0, int p1) {}
void __stdcall SetProcessShutdownParameters(int p0, int p1) {}
void __stdcall SetProcessWorkingSetSize(int p0, int p1, int p2) {}
void __stdcall SetProcessWorkingSetSizeEx(int p0, int p1, int p2, int p3) {}
void __stdcall SetProtectedPolicy(int p0, int p1, int p2) {}
void __stdcall SetSearchPathMode(int p0) {}
void __stdcall SetStdHandle(int p0, int p1) {}
void __stdcall SetStdHandleEx(int p0, int p1, int p2) {}
void __stdcall SetSystemFileCacheSize(int p0, int p1, int p2) {}
void __stdcall SetSystemPowerState(int p0, int p1) {}
void __stdcall SetSystemTime(int p0) {}
void __stdcall SetSystemTimeAdjustment(int p0, int p1) {}
void __stdcall SetTapeParameters(int p0, int p1, int p2) {}
void __stdcall SetTapePosition(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall SetThreadAffinityMask(int p0, int p1) {}
void __stdcall SetThreadContext(int p0, int p1) {}
void __stdcall SetThreadDescription(int p0, int p1) {}
void __stdcall SetThreadErrorMode(int p0, int p1) {}
void __stdcall SetThreadExecutionState(int p0) {}
void __stdcall SetThreadGroupAffinity(int p0, int p1, int p2) {}
void __stdcall SetThreadIdealProcessor(int p0, int p1) {}
void __stdcall SetThreadIdealProcessorEx(int p0, int p1, int p2) {}
void __stdcall SetThreadInformation(int p0, int p1, int p2, int p3) {}
void __stdcall SetThreadLocale(int p0) {}
void __stdcall SetThreadPreferredUILanguages(int p0, int p1, int p2) {}
void __stdcall SetThreadPreferredUILanguages2(int p0, int p1, int p2, int p3) {}
void __stdcall SetThreadPriority(int p0, int p1) {}
void __stdcall SetThreadPriorityBoost(int p0, int p1) {}
void __stdcall SetThreadSelectedCpuSetMasks(int p0, int p1, int p2) {}
void __stdcall SetThreadSelectedCpuSets(int p0, int p1, int p2) {}
void __stdcall SetThreadStackGuarantee(int p0) {}
void __stdcall SetThreadUILanguage(int p0) {}
void __stdcall SetThreadpoolStackInformation(int p0, int p1) {}
void __stdcall SetThreadpoolThreadMaximum(int p0, int p1) {}
void __stdcall SetThreadpoolThreadMinimum(int p0, int p1) {}
void __stdcall SetThreadpoolTimer(int p0, int p1, int p2, int p3) {}
void __stdcall SetThreadpoolTimerEx(int p0, int p1, int p2, int p3) {}
void __stdcall SetThreadpoolWait(int p0, int p1, int p2) {}
void __stdcall SetThreadpoolWaitEx(int p0, int p1, int p2, int p3) {}
void __stdcall SetTimeZoneInformation(int p0) {}
void __stdcall SetTimerQueueTimer(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall SetUmsThreadInformation(int p0, int p1, int p2, int p3) {}
void __stdcall SetUnhandledExceptionFilter(int p0) {}
void __stdcall SetUserGeoID(int p0) {}
void __stdcall SetUserGeoName(int p0) {}
void __stdcall SetVolumeLabelA(int p0, int p1) {}
void __stdcall SetVolumeLabelW(int p0, int p1) {}
void __stdcall SetVolumeMountPointA(int p0, int p1) {}
void __stdcall SetVolumeMountPointW(int p0, int p1) {}
void __stdcall SetWaitableTimer(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall SetWaitableTimerEx(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall SetXStateFeaturesMask(int p0, int p1, int p2) {}
void __stdcall SetupComm(int p0, int p1, int p2) {}
void __stdcall SignalObjectAndWait(int p0, int p1, int p2, int p3) {}
void __stdcall SizeofResource(int p0, int p1) {}
void __stdcall Sleep(int p0) {}
void __stdcall SleepConditionVariableCS(int p0, int p1, int p2) {}
void __stdcall SleepConditionVariableSRW(int p0, int p1, int p2, int p3) {}
void __stdcall SleepEx(int p0, int p1) {}
void __stdcall StartThreadpoolIo(int p0) {}
void __stdcall SubmitThreadpoolWork(int p0) {}
void __stdcall SuspendThread(int p0) {}
void __stdcall SwitchToFiber(int p0) {}
void __stdcall SwitchToThread() {}
void __stdcall SystemTimeToFileTime(int p0, int p1) {}
void __stdcall SystemTimeToTzSpecificLocalTime(int p0, int p1, int p2) {}
void __stdcall SystemTimeToTzSpecificLocalTimeEx(int p0, int p1, int p2) {}
void __stdcall TerminateJobObject(int p0, int p1) {}
void __stdcall TerminateProcess(int p0, int p1) {}
void __stdcall TerminateThread(int p0, int p1) {}
void __stdcall Thread32First(int p0, int p1) {}
void __stdcall Thread32Next(int p0, int p1) {}
void __stdcall TlsAlloc() {}
void __stdcall TlsFree(int p0) {}
void __stdcall TlsGetValue(int p0) {}
void __stdcall TlsSetValue(int p0, int p1) {}
void __stdcall Toolhelp32ReadProcessMemory(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall TransactNamedPipe(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall TransmitCommChar(int p0, int p1) {}
void __stdcall TryAcquireSRWLockExclusive(int p0) {}
void __stdcall TryAcquireSRWLockShared(int p0) {}
void __stdcall TryEnterCriticalSection(int p0) {}
void __stdcall TrySubmitThreadpoolCallback(int p0, int p1, int p2) {}
void __stdcall TzSpecificLocalTimeToSystemTime(int p0, int p1, int p2) {}
void __stdcall TzSpecificLocalTimeToSystemTimeEx(int p0, int p1, int p2) {}
void __stdcall UmsThreadYield(int p0) {}
void __stdcall UnhandledExceptionFilter(int p0) {}
void __stdcall UnlockFile(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall UnlockFileEx(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall UnmapViewOfFile(int p0) {}
void __stdcall UnmapViewOfFileEx(int p0, int p1) {}
void __stdcall UnregisterApplicationRecoveryCallback() {}
void __stdcall UnregisterApplicationRestart() {}
void __stdcall UnregisterBadMemoryNotification(int p0) {}
void __stdcall UnregisterWait(int p0) {}
void __stdcall UnregisterWaitEx(int p0, int p1) {}
void __stdcall UnregisterWaitUntilOOBECompleted(int p0) {}
void __stdcall UpdateCalendarDayOfWeek(int p0) {}
void __stdcall UpdateProcThreadAttribute(int p0, int p1, int p2, int p3, int p4, int p5, int p6) {}
void __stdcall UpdateResourceA(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall UpdateResourceW(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall VerLanguageNameA(int p0, int p1, int p2) {}
void __stdcall VerLanguageNameW(int p0, int p1, int p2) {}
void __stdcall VerSetConditionMask(int p0, int p1, int p2, int p3) {}
void __stdcall VerifyScripts(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall VerifyVersionInfoA(int p0, int p1, int p2, int p3) {}
void __stdcall VerifyVersionInfoW(int p0, int p1, int p2, int p3) {}
void __stdcall VirtualAlloc(int p0, int p1, int p2, int p3) {}
void __stdcall VirtualAllocEx(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall VirtualAllocExNuma(int p0, int p1, int p2, int p3, int p4, int p5) {}
void __stdcall VirtualFree(int p0, int p1, int p2) {}
void __stdcall VirtualFreeEx(int p0, int p1, int p2, int p3) {}
void __stdcall VirtualLock(int p0, int p1) {}
void __stdcall VirtualProtect(int p0, int p1, int p2, int p3) {}
void __stdcall VirtualProtectEx(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall VirtualQuery(int p0, int p1, int p2) {}
void __stdcall VirtualQueryEx(int p0, int p1, int p2, int p3) {}
void __stdcall VirtualUnlock(int p0, int p1) {}
void __stdcall WTSGetActiveConsoleSessionId() {}
void __stdcall WaitCommEvent(int p0, int p1, int p2) {}
void __stdcall WaitForDebugEvent(int p0, int p1) {}
void __stdcall WaitForDebugEventEx(int p0, int p1) {}
void __stdcall WaitForMultipleObjects(int p0, int p1, int p2, int p3) {}
void __stdcall WaitForMultipleObjectsEx(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall WaitForSingleObject(int p0, int p1) {}
void __stdcall WaitForSingleObjectEx(int p0, int p1, int p2) {}
void __stdcall WaitForThreadpoolIoCallbacks(int p0, int p1) {}
void __stdcall WaitForThreadpoolTimerCallbacks(int p0, int p1) {}
void __stdcall WaitForThreadpoolWaitCallbacks(int p0, int p1) {}
void __stdcall WaitForThreadpoolWorkCallbacks(int p0, int p1) {}
void __stdcall WaitNamedPipeA(int p0, int p1) {}
void __stdcall WaitNamedPipeW(int p0, int p1) {}
void __stdcall WakeAllConditionVariable(int p0) {}
void __stdcall WakeConditionVariable(int p0) {}
void __stdcall WerGetFlags(int p0, int p1) {}
void __stdcall WerRegisterAdditionalProcess(int p0, int p1) {}
void __stdcall WerRegisterAppLocalDump(int p0) {}
void __stdcall WerRegisterCustomMetadata(int p0, int p1) {}
void __stdcall WerRegisterExcludedMemoryBlock(int p0, int p1) {}
void __stdcall WerRegisterFile(int p0, int p1, int p2) {}
void __stdcall WerRegisterMemoryBlock(int p0, int p1) {}
void __stdcall WerRegisterRuntimeExceptionModule(int p0, int p1) {}
void __stdcall WerSetFlags(int p0) {}
void __stdcall WerUnregisterAdditionalProcess(int p0) {}
void __stdcall WerUnregisterAppLocalDump() {}
void __stdcall WerUnregisterCustomMetadata(int p0) {}
void __stdcall WerUnregisterExcludedMemoryBlock(int p0) {}
void __stdcall WerUnregisterFile(int p0) {}
void __stdcall WerUnregisterMemoryBlock(int p0) {}
void __stdcall WerUnregisterRuntimeExceptionModule(int p0, int p1) {}
void __stdcall WideCharToMultiByte(int p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7) {}
void __stdcall WinExec(int p0, int p1) {}
void __stdcall Wow64DisableWow64FsRedirection(int p0) {}
void __stdcall Wow64EnableWow64FsRedirection(int p0) {}
void __stdcall Wow64GetThreadContext(int p0, int p1) {}
void __stdcall Wow64GetThreadSelectorEntry(int p0, int p1, int p2) {}
void __stdcall Wow64RevertWow64FsRedirection(int p0) {}
void __stdcall Wow64SetThreadContext(int p0, int p1) {}
void __stdcall Wow64SuspendThread(int p0) {}
void __stdcall WriteConsoleA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall WriteConsoleInputA(int p0, int p1, int p2, int p3) {}
void __stdcall WriteConsoleInputW(int p0, int p1, int p2, int p3) {}
void __stdcall WriteConsoleOutputA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall WriteConsoleOutputAttribute(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall WriteConsoleOutputCharacterA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall WriteConsoleOutputCharacterW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall WriteConsoleOutputW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall WriteConsoleW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall WriteFile(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall WriteFileEx(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall WriteFileGather(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall WritePrivateProfileSectionA(int p0, int p1, int p2) {}
void __stdcall WritePrivateProfileSectionW(int p0, int p1, int p2) {}
void __stdcall WritePrivateProfileStringA(int p0, int p1, int p2, int p3) {}
void __stdcall WritePrivateProfileStringW(int p0, int p1, int p2, int p3) {}
void __stdcall WritePrivateProfileStructA(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall WritePrivateProfileStructW(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall WriteProcessMemory(int p0, int p1, int p2, int p3, int p4) {}
void __stdcall WriteProfileSectionA(int p0, int p1) {}
void __stdcall WriteProfileSectionW(int p0, int p1) {}
void __stdcall WriteProfileStringA(int p0, int p1, int p2) {}
void __stdcall WriteProfileStringW(int p0, int p1, int p2) {}
void __stdcall WriteTapemark(int p0, int p1, int p2, int p3) {}
void __stdcall ZombifyActCtx(int p0) {}
void __stdcall _hread(int p0, int p1, int p2) {}
void __stdcall _hwrite(int p0, int p1, int p2) {}
void __stdcall _lclose(int p0) {}
void __stdcall _lcreat(int p0, int p1) {}
void __stdcall _llseek(int p0, int p1, int p2) {}
void __stdcall _lopen(int p0, int p1) {}
void __stdcall _lread(int p0, int p1, int p2) {}
void __stdcall _lwrite(int p0, int p1, int p2) {}
void __stdcall lstrcatA(int p0, int p1) {}
void __stdcall lstrcatW(int p0, int p1) {}
void __stdcall lstrcmpA(int p0, int p1) {}
void __stdcall lstrcmpW(int p0, int p1) {}
void __stdcall lstrcmpiA(int p0, int p1) {}
void __stdcall lstrcmpiW(int p0, int p1) {}
void __stdcall lstrcpyA(int p0, int p1) {}
void __stdcall lstrcpyW(int p0, int p1) {}
void __stdcall lstrcpynA(int p0, int p1, int p2) {}
void __stdcall lstrcpynW(int p0, int p1, int p2) {}
void __stdcall lstrlenA(int p0) {}
void __stdcall lstrlenW(int p0) {}
void __stdcall uaw_lstrcmpW(int p0, int p1) {}
void __stdcall uaw_lstrcmpiW(int p0, int p1) {}
void __stdcall uaw_lstrlenW(int p0) {}
void __stdcall uaw_wcschr(int p0, int p1) {}
void __stdcall uaw_wcscpy(int p0, int p1) {}
void __stdcall uaw_wcsicmp(int p0, int p1) {}
void __stdcall uaw_wcslen(int p0) {}
void __stdcall uaw_wcsrchr(int p0, int p1) {}
